@@ -355,7 +355,6 @@ class Counter(object):
                                                  % len(self.files))
                                 sys.stdout.flush()
             print("", end="\r")
-            print(str(len(self.files)) + " unique files")
 
     @timer
     def discover(self):
@@ -367,6 +366,8 @@ class Counter(object):
         self.hashes = {}
 
         def isfile(obj):
+            """Check whether a file or not
+            """
             if type(obj) is str and os.path.isfile(obj):
                 return True
         if type(self.root) is str and os.path.isfile(self.root):
@@ -384,6 +385,7 @@ class Counter(object):
                     self.walker(fpath=fpath)
                 else:
                     print("Invalid path specified: %s" % fpath)
+        print(str(len(self.files)) + " unique files")
 
     @timer
     def count(self):
